@@ -2,7 +2,7 @@ var searchData=
 [
   ['d_0',['d',['../structDav1dSegmentationDataSet.html#a9a5f7c927df14d61f15d06cb0d359f09',1,'Dav1dSegmentationDataSet']]],
   ['damping_1',['damping',['../structDav1dFrameHeader.html#a367442febb62bbcc539c17f473bda63b',1,'Dav1dFrameHeader']]],
-  ['data_2',['data',['../structDav1dPicture.html#ae6a2b8538d7a43aaab3f46d2198e67fa',1,'Dav1dPicture::data()'],['../structDav1dFrameHeader.html#a0793ad1ee6079e66307a11c3b3bb6432',1,'Dav1dFrameHeader::data()'],['../structDav1dData.html#a08e47b7276c43111369e43439f8cfe9f',1,'Dav1dData::data()'],['../structDav1dUserData.html#abea83576f25527ba0b464d28e86f2757',1,'Dav1dUserData::data()']]],
+  ['data_2',['data',['../structDav1dPicture.html#ae6a2b8538d7a43aaab3f46d2198e67fa',1,'Dav1dPicture::data'],['../structDav1dFrameHeader.html#a0793ad1ee6079e66307a11c3b3bb6432',1,'Dav1dFrameHeader::data'],['../structDav1dData.html#a08e47b7276c43111369e43439f8cfe9f',1,'Dav1dData::data'],['../structDav1dUserData.html#abea83576f25527ba0b464d28e86f2757',1,'Dav1dUserData::data']]],
   ['data_2eh_3',['data.h',['../data_8h.html',1,'']]],
   ['dav1d_2eh_4',['dav1d.h',['../dav1d_8h.html',1,'']]],
   ['dav1d_5fadaptive_5',['DAV1D_ADAPTIVE',['../headers_8h.html#ad2bd41511ca43ef7d9ebf5cb2eaca6c5a66e6af92cf2d442f04a1dd7cab7e2a02',1,'headers.h']]],
@@ -177,7 +177,7 @@ var searchData=
   ['decoder_5fbuffer_5fdelay_174',['decoder_buffer_delay',['../structDav1dSequenceHeader_1_1Dav1dSequenceHeaderOperatingParameterInfo.html#af793e75b7698824189eb9fb506e3ba91',1,'Dav1dSequenceHeader::Dav1dSequenceHeaderOperatingParameterInfo']]],
   ['decoder_5fmodel_5finfo_5fpresent_175',['decoder_model_info_present',['../structDav1dSequenceHeader.html#a6bab00a018e0a1ffb7c01eca7cd2e1d6',1,'Dav1dSequenceHeader']]],
   ['decoder_5fmodel_5fparam_5fpresent_176',['decoder_model_param_present',['../structDav1dSequenceHeader_1_1Dav1dSequenceHeaderOperatingPoint.html#a4c798f7eb4166a61cbcd3149b5553ddc',1,'Dav1dSequenceHeader::Dav1dSequenceHeaderOperatingPoint']]],
-  ['delta_177',['delta',['../structDav1dWarpedMotionParams.html#a4eb152e946d0c075cec1007857f480ad',1,'Dav1dWarpedMotionParams::delta()'],['../structDav1dFrameHeader.html#ac1e90b1fcfbcb834a3c9f051cd3774cf',1,'Dav1dFrameHeader::delta()']]],
+  ['delta_177',['delta',['../structDav1dWarpedMotionParams.html#a4eb152e946d0c075cec1007857f480ad',1,'Dav1dWarpedMotionParams::delta'],['../structDav1dFrameHeader.html#ac1e90b1fcfbcb834a3c9f051cd3774cf',1,'Dav1dFrameHeader::delta']]],
   ['delta_5fframe_5fid_5fn_5fbits_178',['delta_frame_id_n_bits',['../structDav1dSequenceHeader.html#ac9e01409b43b5ec65ae98c911234ce40',1,'Dav1dSequenceHeader']]],
   ['delta_5flf_5fu_179',['delta_lf_u',['../structDav1dSegmentationData.html#ae61b74492ae6ee1320d1663dd907e0ea',1,'Dav1dSegmentationData']]],
   ['delta_5flf_5fv_180',['delta_lf_v',['../structDav1dSegmentationData.html#ac7f645e6d299541eb72829c007e01fc5',1,'Dav1dSegmentationData']]],
